Skip to contents

Find duplicates within a vector

Usage

findDuplicates(input)

Arguments

input

Vector of values.

Value

Vector of values from input that appear at least twice. Each value that appears N times in input will appear N-1 times in the output.