Uses the information from the shared edge to update the merged PCs,
area, number of points, and perimeter. Mutates the e_merge_fromth value
within the V_pcs, V_npts, V_perimeter, V_area input data structures.
Uses the information from the shared edge to update the merged PCs,
area, number of points, and perimeter. Mutates the e_merge_fromth value
within the V_pcs, V_npts, V_perimeter, V_area input data structures.