Expresses the 2 x D total derivative at each location as
a pair of 2-dimensional vectors in the gradient and orthogonal
directions.
Value
A N x 6 matrix with the following attributes for
each location:
- dx grad,dy grad
x,y directions of unit vector in the direction of greatest change (first singular vector).
- dx ortho,dy ortho
x,y directions of unit vector orthogonal to the direction of greatest change (second singular vector).
- |grad|,|ortho|
Magnitude of directional derivative in the gradient and orthogonal directions (singular values).