R/utils_dmt.R
dmt_assign_tiles.Rd
Tiles are defined as points that are in the same connected component in the mesh after discounting separatrix edges.
dmt_assign_tiles(dmt)
A DMT data structure with edges, pts, and e_sep attributes.
edges
pts
e_sep
A DMT data structure with the following additional attributes:
pts$agg_id: Unique ID for the tile that each point belongs to.
pts$agg_id
edges$agg_from: Unique ID for the tile that edges$from_pt belongs to.
edges$agg_from
edges$from_pt
edges$agg_to: Unique ID for the tile that edges$to_pt belongs to.
edges$agg_to
edges$to_pt