Initialize tiles with shapes and other properties
Value
A list data structure for tiles and their adjacencies. Includes the following attributes:
meta_data: A data table with attributes for tiles:X,Y: Centroid of each tile.npts: Number of points in each tile.shape: Asfclist-column with the geometries for each tile.area,perimeter: Area and perimeter of each tile.
edges: A data table with attributes for edges between adjacent tiles:from,to: Tile IDs for the two tiles bordering this edge.x0,y0,x1,y1: Centroid coordinates for the two tiles bordering this edge.area,npts: Sum of areas and numbers of points in the two tiles bordering this edge.edge_length: Total length of the border between thefromandtotiles.
pcs: Anum_tilesxnpcsmatrix with the average embedding value over all cells in each tile.