Constructs a directed maximum spanning forest from point and edge scalar values using a version of Prim's algorithm. Critical points (local maxima; or, more precisely, an endpoint of an edge that is a local maxima) are used as roots for each tree in the forest, and edges that would bridge two trees with different critical point roots are marked as possible saddle edges.
Value
A List with the following attributes (all indices are 1-indexed):
edges: Aforest_sizex2matrix where each row is a directed edge in the maximum spanning forest. The first column has the source point for each edge and the second column has the target point.saddles: A lengthnum_saddlesvector with edge indices for possible saddle edges.labels: A lengthnum_pointsvector of labels for the connected components in the maximum spanning tree. Each connected component is labeled by the index of its critical point.critpts: A lengthnum_critptsvector of critical points (maxima).parent: A lengthnum_pointsvector containing the parent (source) point for each point in the directed spanning forest. Critical points have no parent, so the value should be ignored.parent_edge: A lengthnum_pointsvector containing the directed edge that has each point as a target node. Critical points have no parent edge, so the value should be ignored.