First, log-normalizes and Z-scores the counts matrix and then performs PCA using SVD.
Value
A list with two features:
loadings: An_genesxnpcsmatrix of gene loadings for each PC. Each column is a unit vector.embeddings: An_cellsxnpcsmatrix of cell embeddings across all PCs. Each column j has magnitude equal to the jth singular value. That is, PCs with larger contribution to the total variance will have embeddings of proportionally larger magnitude.