Compute a spatial gradient field along each edge
Source:R/RcppExports.R
estimate_field_edges_cpp.RdDistance between neighboring cells is normalized to unit distance so that only the orientation of each edge matters. The gradient is then the difference in expression of each embedding dimension between the two endpoints of the edge.