R/RcppExports.R
findDuplicates.Rd
Find duplicates within a vector
findDuplicates(input)
Vector of values.
Vector of values from input that appear at least twice. Each value that appears N times in input will appear N-1 times in the output.
input