Get the collection of edges that lie along separatrices
Arguments
- epaths
A list of length
2*num_saddlescontaining the two paths from each saddle edge to the two critical points that it joins. Each path is a numeric vector of edge indices (1-indexed).- saddles
A length
num_saddlesvector with edge indices for saddle edges (1-indexed).- nedges
Total number of edges in the mesh.