Trace back from a point to its root in the spanning forest
Source:R/RcppExports.R
trace_back_cpp.RdTrace back from a point to its root in the spanning forest
Arguments
- v0
Index of starting point (0-indexed).
- vcrit
Index of critical point associated with the tree that
v0belongs to (0-indexed).- parent_edge
A length
num_pointsvector containing the directed edge that has each point as a target node. Critical points have no parent edge, so the value is ignored.- parent
A length
num_pointsvector containing the parent (source) point for each point in the directed spanning forest. Critical points have no parent, so the value is ignored.