Trace all paths from saddles to critical points in the spanning forest
Source:R/RcppExports.R
trace_epaths_cpp.RdTrace all paths from saddles to critical points in the spanning forest
Arguments
- saddles
A length
num_saddlesvector with edge indices for saddle edges (0-indexed).- vcrits
A length
num_critptsvector of critical points.- edges_from
A length
num_edgesvector with indices for the first end-point of each edge in the mesh (0-indexed).- edges_to
A length
num_edgesvector with indices for the second end-point of each edge in the mesh (0-indexed).- parent_edge
A length
num_pointsvector containing the directed edge that has each point as a target node in the directed spanning forest. Critical points have no parent edge, so the value is ignored.- parent
A length
num_pointsvector containing the parent (source) point for each point in the directed spanning forest. Critical points have no parent, so the value is ignored.