For every boundary that exists between the new merged tile and other tiles, the following values must be updated:
E_pcs_merge[e_update,]: PCs that would result from future merging.E_perimeter_merge[e_update]: Perimeters that would result from future merging.E_w[e_update]: Expression similarity score.E_score_size[e_update]: Size of merged tile score.dC[e_update]: Delta shape compactness score for merged tile.E_dscore[e_update]: Overall merging score (product ofw,score_size,dC) Note thatE_nptsandE_areashould already have been previously updated.