Update shapes and counts matrix for tiles after merging
Source:R/utils_aggregation.R
update_agg_shapes.RdUpdate shapes and counts matrix for tiles after merging
Value
aggs tile data structure with updated values for:
- meta_data$shape
Retraces the polygons for tiles using the new point assignments.
- meta_data$X,meta_data$Y
Recomputes the centroid of each tile from the polygon shape.
- edges
Ensures that
aggs$edgesalways hasfrom<to.- counts
A
num_genesxnum_tilesgene-by-tile matrix of aggregated transcript counts.